@@ -11,16 +11,9 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""
-$Id: tests.py 70182 2006-09-14 20:39:46Z jukart $
-"""
-__docformat__ = 'restructuredtext'
-
-import unittest
-
-from zope.testing import doctest
-from zope.testing.doctestunit import DocFileSuite
 from zope.app.testing import setup
+import doctest
+import unittest
 
 
 def setUp(test):
@@ -33,13 +26,7 @@ def tearDown(test):
 
 
 def test_suite():
-    return unittest.TestSuite((
-        DocFileSuite('README.txt',
-            setUp=setUp, tearDown=tearDown,
-            optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
-            ),
-        ))
-
-
-if __name__ == '__main__':
-    unittest.main(defaultTest='test_suite')
+    return doctest.DocFileSuite(
+        'README.txt',
+        setUp=setUp, tearDown=tearDown,
+        optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS)
